@@ -5,7 +5,7 @@ Nginx
 This module provides high-level tools for installing the `nginx`_
 web server and managing the configuration of web sites.
 
-.. nginx: http://nginx.org/
+.. _nginx: http://nginx.org/
 
 """
 from __future__ import with_statement
@@ -29,15 +29,17 @@ from fabtools.utils import run_as_root
 
 def server(package_name='nginx'):
     """
-    Require nginx server to be installed and running.
-    Allows override of package name, this allow to install other packages like
-    `nginx-extras` or `nginx-light`.
+    Require the nginx web server to be installed and running.
+
+    You can override the system package name, if you need to install
+    a specific variant such as `nginx-extras` or `nginx-light`.
 
     ::
 
         from fabtools import require
 
         require.nginx.server()
+
     """
     package(package_name)
     require_started('nginx')
@@ -45,8 +47,16 @@ def server(package_name='nginx'):
 
 def enabled(config):
     """
-    Ensure link to /etc/nginx/sites-available/config exists and reload nginx
-    configuration if needed.
+    Require an nginx site to be enabled.
+
+    This will cause nginx to reload its configuration.
+
+    ::
+
+        from fabtools import require
+
+        require.nginx.enabled('mysite')
+
     """
     enable(config)
     reload_service('nginx')
@@ -54,8 +64,16 @@ def enabled(config):
 
 def disabled(config):
     """
-    Ensure link to /etc/nginx/sites-available/config doesn't exist and reload
-    nginx configuration if needed.
+    Require an nginx site to be disabled.
+
+    This will cause nginx to reload its configuration.
+
+    ::
+
+        from fabtools import require
+
+        require.nginx.site_disabled('default')
+
     """
     disable(config)
     reload_service('nginx')
@@ -82,7 +100,8 @@ def site(server_name, template_contents=None, template_source=None,
             access_log  /var/log/nginx/%(server_name)s.log;
         }'''
 
-        require.nginx.site('example.com', template_contents=CONFIG_TPL,
+        require.nginx.site('example.com',
+            template_contents=CONFIG_TPL,
             port=80,
             server_alias='www.example.com',
             docroot='/var/www/mysite',
@@ -91,7 +110,7 @@ def site(server_name, template_contents=None, template_source=None,
     .. seealso:: :py:func:`fabtools.require.files.template_file`
     """
     if not is_installed('nginx-common'):
-        # nginx-common is always installed if Nginx exists
+        # nginx-common is always installed if nginx exists
         server()
 
     config_filename = '/etc/nginx/sites-available/%s.conf' % server_name
