@@ -54,9 +54,10 @@ def user(name, password, superuser=False, createdb=False,
          createrole=False, inherit=True, login=True, connection_limit=None,
          encrypted_password=False):
     """
-    Require the existence of a PostgreSQL user. The password and options
-    provided will only be applied when creating a new user (existing
-    users will *not* be modified).
+    Require the existence of a PostgreSQL user.
+
+    The password and options provided will only be applied when creating
+    a new user (existing users will *not* be modified).
 
     ::
 
