@@ -50,6 +50,8 @@ def setuptools(version=MIN_SETUPTOOLS_VERSION, python_cmd='python'):
             require_deb_package('python-dev')
         elif family == 'redhat':
             require_rpm_package('python-devel')
+        elif family == 'arch':
+            pass # ArchLinux installs header with base package
         else:
             raise UnsupportedFamily(supported=['debian', 'redhat'])
 
