@@ -64,9 +64,11 @@ def process(name, **kwargs):
     elif family == 'redhat':
         require_rpm_package('supervisor')
         require_started('supervisord')
-    elif distrib_id() is 'Archlinux':
+    elif family == 'arch':
         require_arch_package('supervisor')
         require_started('supervisord')
+    else:
+        raise UnsupportedFamily(supported=['debian', 'redhat', 'arch'])
 
     # Set default parameters
     params = {}
@@ -83,10 +85,10 @@ def process(name, **kwargs):
     # Upload config file
     if family == 'debian':
         filename = '/etc/supervisor/conf.d/%(name)s.conf' % locals()
-    elif family in ['redhat', 'arch']:
+    elif family == 'redhat':
         filename = '/etc/supervisord.d/%(name)s.ini' % locals()
-    else:
-        raise UnsupportedFamily(supported=['debian', 'redhat', 'arch'])
+    elif family == 'arch':
+        filename = '/etc/supervisor.d/%(name)s.ini' % locals()
 
     with watch(filename, callback=update_config, use_sudo=True):
         require_file(filename, contents='\n'.join(lines), use_sudo=True)
